==> gromacs_3.3.1.orig.tar.gz: gromacs-3.3.1/src/kernel/luck.c <==
/*
 * $Id: luck.c,v 1.11.4.1 2005/09/02 20:14:37 spoel Exp $
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include "copyrite.h"
#include "string.h"
#include "statutil.h"

int main(int argc,char *argv[])
{
  char quote[256];
  
  /* Necessary to find the library directory before installation */
  set_program_name(argv[0]);

  if ( argc == 2 ) 
    if ( strcmp(argv[1],"-c")==0)
      CopyRight(stdout,argv[0]);
  thanx(stdout);
  /*printf("%s\n",cool_quote(quote,255,NULL));*/
  return 0;
}

==> gromacs_3.3.3.orig.tar.gz: gromacs-3.3.3/src/kernel/luck.c <==
/*
 * $Id: luck.c,v 1.11.4.5 2008/02/29 07:02:45 spoel Exp $
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.3.3
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2008, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Groningen Machine for Chemical Simulation
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include "copyrite.h"
#include "string.h"
#include "statutil.h"

int 
main(int argc,char *argv[])
{
  char quote[256];
  int  i,bc=0,bb=0;
  
  /* Necessary to find the library directory before installation */
  set_program_name(argv[0]);

  for(i=1; (i<argc); i++)
    if ( strcmp(argv[i],"-c")==0)
      bc = 1;
    else if ( strcmp(argv[i],"-b")==0)
      bb = 1;
      
  if (bc)
    CopyRight(stdout,ShortProgram());
    
  if (bb) {
    bromacs(quote,255);
    printf("%s\n",quote);
  }
    
  thanx(stdout);
  return 0;
}
